(function ($) {

  /**
   * Bind a function to the post add features trigger.
   *
   * This function creates a superBounds LatLngBounds object.
   * This object is populated by the accumulated bounds from
   * all added features. This object is then used to pass to
   * the fitBounds leaflet method which zooms and centres the
   * map to cover all the features.
   */
  $(document).bind('leaflet.features', function (e, exist, leaflet) {
    var superBounds = new L.LatLngBounds();
    var map = leaflet.lMap;

    // Iterated over all the layers in the map.
    for (var l in map._layers) {
      var overlay = map._layers[l];
      if (overlay._layers) {
        // Iterate over all the features.
        for (var f in overlay._layers) {
          var feature = overlay._layers[f];
          var bounds;
          if (feature.getBounds) {
            bounds = feature.getBounds();
          }
          else if (feature._latlng) {
            bounds = L.latLngBounds(feature._latlng, feature._latlng);
          }
          // Extend the superBounds with our feature's bounds.
          if (bounds) {
            superBounds.extend(bounds);
          }
        }
      }
    }
    // Fit the map to the superBounds.
    leaflet.lMap.fitBounds(superBounds);
  });

})(jQuery);